Re-exports
pub use eure_parol as parol;pub use query_flow;
Modules
- data_
model - Data structure for representing a data-model of Eure.
- document
- query
- Query-flow queries for Eure language processing.
- report
- Unified error reporting IR for Eure.
- tree
- value
Macros
- eure
- A declarative macro for building Eure documents, inspired by serde_json’s
json!macro.
Structs
- Schema
Builder - Builder for constructing schema documents from Rust types.
- Schema
Document - Schema document with arena-based node storage
Traits
- Build
Schema Trait - Trait for types that can build their schema representation.
- From
Eure - Trait for parsing Rust types from Eure documents.
Functions
- parse_
content - Parse Eure content directly into a typed value.