Crate eure

Crate eure 

Re-exports

pub use eure_parol as parol;
pub use query_flow;

Modules

data_model
Data structure for representing a data-model of Eure.
document
query
Query-flow queries for Eure language processing.
report
Unified error reporting IR for Eure.
tree
value

Macros

eure
A declarative macro for building Eure documents, inspired by serde_json’s json! macro.

Structs

SchemaBuilder
Builder for constructing schema documents from Rust types.
SchemaDocument
Schema document with arena-based node storage

Traits

BuildSchemaTrait
Trait for types that can build their schema representation.
FromEure
Trait for parsing Rust types from Eure documents.

Functions

parse_content
Parse Eure content directly into a typed value.

Derive Macros

BuildSchema
FromEure